@@ -242,14 +242,6 @@ export function trackRulesSearchComponentInteraction(filter: keyof RulesFilter)
 export function trackRulesListViewChange(payload: { view: string }) {
   reportInteraction('grafana_alerting_rules_list_mode', { ...payload });
 }
-export function trackSwitchToSimplifiedRouting() {
-  reportInteraction('grafana_alerting_switch_to_simplified_routing');
-}
-
-export function trackSwitchToPoliciesRouting() {
-  reportInteraction('grafana_alerting_switch_to_policies_routing');
-}
-
 export function trackEditInputWithTemplate() {
   reportInteraction('grafana_alerting_contact_point_form_edit_input_with_template');
 }
