@@ -1,14 +1,20 @@
 import { PanelPlugin } from '@grafana/data';
-import { BigValueColorMode, BigValueGraphMode, BigValueJustifyMode, BigValueTextMode } from '@grafana/schema';
+import {
+  BigValueColorMode,
+  BigValueGraphMode,
+  BigValueJustifyMode,
+  BigValueTextMode,
+  PercentChangeColorMode,
+} from '@grafana/schema';
 import { commonOptionsBuilder, sharedSingleStatMigrationHandler } from '@grafana/ui';
 
 import { statPanelChangedHandler } from './StatMigrations';
 import { StatPanel } from './StatPanel';
 import { addStandardDataReduceOptions, addOrientationOption } from './common';
-import { defaultPanelOptions, PanelOptions } from './panelcfg.gen';
+import { defaultOptions, Options } from './panelcfg.gen';
 import { StatSuggestionsSupplier } from './suggestions';
 
-export const plugin = new PanelPlugin<PanelOptions>(StatPanel)
+export const plugin = new PanelPlugin<Options>(StatPanel)
   .useFieldConfig()
   .setPanelOptions((builder) => {
     const mainCategory = ['Stat styles'];
@@ -17,22 +23,36 @@ export const plugin = new PanelPlugin<PanelOptions>(StatPanel)
     addOrientationOption(builder, mainCategory);
     commonOptionsBuilder.addTextSizeOptions(builder);
 
-    builder.addSelect({
-      path: 'textMode',
-      name: 'Text mode',
-      description: 'Control if name and value is displayed or just name',
-      category: mainCategory,
-      settings: {
-        options: [
-          { value: BigValueTextMode.Auto, label: 'Auto' },
-          { value: BigValueTextMode.Value, label: 'Value' },
-          { value: BigValueTextMode.ValueAndName, label: 'Value and name' },
-          { value: BigValueTextMode.Name, label: 'Name' },
-          { value: BigValueTextMode.None, label: 'None' },
-        ],
-      },
-      defaultValue: defaultPanelOptions.textMode,
-    });
+    builder
+      .addSelect({
+        path: 'textMode',
+        name: 'Text mode',
+        description: 'Control if name and value is displayed or just name',
+        category: mainCategory,
+        settings: {
+          options: [
+            { value: BigValueTextMode.Auto, label: 'Auto' },
+            { value: BigValueTextMode.Value, label: 'Value' },
+            { value: BigValueTextMode.ValueAndName, label: 'Value and name' },
+            { value: BigValueTextMode.Name, label: 'Name' },
+            { value: BigValueTextMode.None, label: 'None' },
+          ],
+        },
+        defaultValue: defaultOptions.textMode,
+      })
+      .addRadio({
+        path: 'wideLayout',
+        name: 'Wide layout',
+        category: mainCategory,
+        settings: {
+          options: [
+            { value: true, label: 'On' },
+            { value: false, label: 'Off' },
+          ],
+        },
+        defaultValue: defaultOptions.wideLayout,
+        showIf: (config) => config.textMode === BigValueTextMode.ValueAndName,
+      });
 
     builder
       .addSelect({
@@ -54,7 +74,7 @@ export const plugin = new PanelPlugin<PanelOptions>(StatPanel)
         name: 'Graph mode',
         description: 'Stat panel graph / sparkline mode',
         category: mainCategory,
-        defaultValue: defaultPanelOptions.graphMode,
+        defaultValue: defaultOptions.graphMode,
         settings: {
           options: [
             { value: BigValueGraphMode.None, label: 'None' },
@@ -65,7 +85,7 @@ export const plugin = new PanelPlugin<PanelOptions>(StatPanel)
       .addRadio({
         path: 'justifyMode',
         name: 'Text alignment',
-        defaultValue: defaultPanelOptions.justifyMode,
+        defaultValue: defaultOptions.justifyMode,
         category: mainCategory,
         settings: {
           options: [
@@ -73,6 +93,27 @@ export const plugin = new PanelPlugin<PanelOptions>(StatPanel)
             { value: BigValueJustifyMode.Center, label: 'Center' },
           ],
         },
+      })
+      .addBooleanSwitch({
+        path: 'showPercentChange',
+        name: 'Show percent change',
+        defaultValue: defaultOptions.showPercentChange,
+        category: mainCategory,
+        showIf: (config) => !config.reduceOptions.values,
+      })
+      .addSelect({
+        path: 'percentChangeColorMode',
+        name: 'Percent change color mode',
+        defaultValue: defaultOptions.percentChangeColorMode,
+        category: mainCategory,
+        settings: {
+          options: [
+            { value: PercentChangeColorMode.Standard, label: 'Standard' },
+            { value: PercentChangeColorMode.Inverted, label: 'Inverted' },
+            { value: PercentChangeColorMode.SameAsValue, label: 'Same as Value' },
+          ],
+        },
+        showIf: (config) => config.showPercentChange,
       });
   })
   .setNoPadding()
